@@ -23,8 +23,15 @@ def do(ctxt):
 		try:
 			cookie[MSGSPERPAGE] = ctxt[MSGSPERPAGE] = int(ctxt['_msgsperpage'])
 		except ValueError: pass
+	if ctxt.has_key('_wrapwidth'):
+		try:
+			cookie[WRAPWIDTH] = ctxt[WRAPWIDTH] = int(ctxt['_wrapwidth'])
+		except ValueError:
+			pass
 	if ctxt.has_key('_alt_part'):
 		cookie[ALTPART] = ctxt[ALTPART] = ctxt['_alt_part']
+	if ctxt.has_key('_date_sort'):
+		cookie[DATESORT] = ctxt[DATESORT] = ctxt['_date_sort']
 	if cookie:
 		for key in cookie.keys():
 			cookie[key]['expires'] = 60*60*24*365*2
