@@ -1,4 +1,5 @@
 ALLOWPOST = intern('allowpost')
+ALLOWRAW = intern('allowraw')
 ALTPART = intern('alt_part')
 AUTHORID = intern('authorid')
 AUTHOR = intern('author')
@@ -7,9 +8,13 @@ BODY = intern('body')
 CLASS = intern('class')
 COMMAND = intern('cmd')
 COOKIES = intern('cookies')
+CSSPREFIX = intern('cssprefix')
 DATE = intern('date')
+DATESORT = intern('date_sort')
 ERROR = intern('error')
 EZMLM = intern('ezmlm')
+FEEDMSGS = intern('feedmsgs')
+FEEDTYPE = intern('feedtype')
 FILENAME = intern('filename')
 FIRSTMONTH = intern('first_month')
 FORMATTIME = intern('format_time')
@@ -21,6 +26,7 @@ LISTDIR = intern('listdir')
 LISTEMAIL = intern('listemail')
 LIST = intern('list')
 LISTSUB = intern('listsub')
+WRAPWIDTH = intern('wrapwidth')
 MENUBAR = intern('menubar')
 MESSAGE = intern('message')
 MESSAGES = intern('messages')
